<?php

require_once 'lib/vod/movie.php';

class ExUaMovie extends Movie implements UserInputHandler
{
    const ID = 'exua_movie';

    public $has_new_series = false;

    public $has_sub_view = false;
    public $sub_view_url = '';
    
    public $resume_off = false;

    public function __construct($id)
    {
        parent::__construct($id);
    }

    public function get_handler_id()
    { return self::ID; }

    public function add_episode($episode)
    {
        $this->series_list[] = $episode;
    }
    
    public function set_sub_view($sub_view_url)
    {
        if (!$sub_view_url || strlen($sub_view_url) == 0)
        {
            $this->has_sub_view = false;
            $this->sub_view_url = '';
        }
        else
        {
            $this->has_sub_view = true;
            $this->sub_view_url = $sub_view_url;
        }
    }

    protected function get_initial_position($initial_series_ndx, &$plugin_cookies)
    {
        $is_audio = $this->series_list[$initial_series_ndx]->is_audio;
        $resume_audio = isset($plugin_cookies->resume_audio) ? $plugin_cookies->resume_audio : 'no';
        if ($is_audio && $resume_audio == 'no')
            return parent::get_initial_position($initial_series_ndx, $plugin_cookies);

        $main_key = $this->id . '.' . $this->series_list[$initial_series_ndx]->playback_url;

        $initial_position_ms = 0;
        if (isset($plugin_cookies->$main_key))
        {
            $t = explode('|', $plugin_cookies->$main_key);
            $pos = intval($t[0]);
            if ($pos < 0)
                $pos = 0;
            if ($pos + 5 >= intval($t[1]))
                $pos = 0;
            $initial_position_ms = $pos * 1000;
       }

        return $initial_position_ms;
    }

    protected function get_movie_actions($initial_series_ndx, &$plugin_cookies)
    {
        $is_audio = $this->series_list[$initial_series_ndx]->is_audio;
        $resume_audio = isset($plugin_cookies->resume_audio) ? $plugin_cookies->resume_audio : 'no';
        if ($is_audio && $resume_audio == 'no')
            return parent::get_movie_actions($initial_series_ndx, $plugin_cookies);
            
        UserInputHandlerRegistry::get_instance()->
            register_handler($this);

        $actions[GUI_EVENT_PLAYBACK_STOP] =
            UserInputHandlerRegistry::create_action($this, 'postroll_watched');
            
        $play_timer = isset($plugin_cookies->play_timer) ? $plugin_cookies->play_timer : 5000;
        if ($play_timer > 0)
        {
            $actions[GUI_EVENT_TIMER] =
                UserInputHandlerRegistry::create_action($this, 'content_timer');
        }
        
        return $actions;        
    }

    protected function get_movie_timer($initial_series_ndx, &$plugin_cookies)
    {
        $is_audio = $this->series_list[$initial_series_ndx]->is_audio;
        $resume_audio = isset($plugin_cookies->resume_audio) ? $plugin_cookies->resume_audio : 'no';
        if ($is_audio && $resume_audio == 'no')
            return parent::get_movie_timer($initial_series_ndx, $plugin_cookies);

        $play_timer = isset($plugin_cookies->play_timer) ? $plugin_cookies->play_timer : 5000;
        if ($play_timer == 0)
            return false;
        
        return array(GuiTimerDef::delay_ms => $play_timer);        
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
//        hd_print('movie: handle_user_input:');
//        foreach ($user_input as $key => $value)
//            hd_print("  $key => $value");
            
        switch ($user_input->control_id)
        {
        case 'postroll_watched':
            $play_timer = isset($plugin_cookies->play_timer) ? $plugin_cookies->play_timer : 5000;
            if ($play_timer == 0)
            {
                $viewed_key = $this->id . '.viewed';
                if (!isset($plugin_cookies->$viewed_key))
                    $plugin_cookies->$viewed_key = '';

                $series_url = $this->series_list[$user_input->plugin_vod_series_ndx]->playback_url;

                $v = $plugin_cookies->$viewed_key;
                $plugin_cookies->$viewed_key = ListUtil::add_item($v, $series_url);
            }            
            return  ActionFactory::invalidate_folders
                    (
                        array
                        (
                            ExUaVodSeriesListScreen::get_media_url_str($this->id)
                        )
                    );
        case 'content_timer': // Watch has started.
            
            $movie_id = $this->id;
            $series_url = $this->series_list[$user_input->plugin_vod_series_ndx]->playback_url;
            $main_key = $movie_id . '.' . $series_url;

            if(!isset($plugin_cookies->$main_key))
            {
                if (isset($plugin_cookies->$movie_id))
                {
                    if (!ListUtil::is_in_list($plugin_cookies->$movie_id, $series_url))
                    {
                        $fav = $plugin_cookies->$movie_id;
                        $plugin_cookies->$movie_id = ListUtil::add_item($fav, $series_url);
                    }
                }
                $ret = shell_exec('cat /tmp/run/ext_command.state | grep playback_duration');
                preg_match('/playback_duration = (\S*)/', $ret, $matches);
                $plugin_cookies->$main_key = 0 . '|' . $matches[1];
            }
            else
            {
                $t = explode('|', $plugin_cookies->$main_key);
                if (intval($t[1]) < 0)
                {
                    $ret = shell_exec('cat /tmp/run/ext_command.state | grep playback_duration');
                    preg_match('/playback_duration = (\S*)/', $ret, $matches);
                    $plugin_cookies->$main_key = 0 . '|' . $matches[1];
                }
            }
            
            $ret = shell_exec('cat /tmp/run/ext_command.state | grep playback_speed');
            preg_match('/playback_speed = (\S*)/', $ret, $matches);
            
            if (intval($matches[1]) > 0)
            {
                $ret = shell_exec('cat /tmp/run/ext_command.state | grep playback_position');
                preg_match('/playback_position = (\S*)/', $ret, $matches);
                if (intval($matches[1]) > 0 )
                {
                    $t = explode('|', $plugin_cookies->$main_key);
                    $plugin_cookies->$main_key = $matches[1] . '|' . $t[1];
                }
            }
            
            $actions[GUI_EVENT_PLAYBACK_STOP] =
                UserInputHandlerRegistry::create_action($this, 'postroll_watched');
                                           
            $actions[GUI_EVENT_TIMER] =
                UserInputHandlerRegistry::create_action($this, 'content_timer');

            $play_timer = isset($plugin_cookies->play_timer) ? $plugin_cookies->play_timer : 5000;
            
            $data = array
                    (
                        ChangeBehaviourActionData::actions => $actions,
                        ChangeBehaviourActionData::timer => array(GuiTimerDef::delay_ms => $play_timer),
                    );

            $params = array(
                'handler_id' => $this->get_handler_id(),
                'control_id' => 'timer');
            
            return array
            (
                GuiAction::handler_string_id => CHANGE_BEHAVIOUR_ACTION_ID,
                GuiAction::caption => null,
                GuiAction::data => $data,
                GuiAction::params => $params,
            );
        }
        
        return null;
    }
}

?>
