<?php

require_once 'lib/list_util.php';
require_once 'lib/abstract_preloaded_regular_screen.php';

require_once 'lib/vod/vod.php';
require_once 'lib/abstract_preloaded_regular_screen.php';

class ExUa_search_history extends AbstractPreloadedRegularScreen
    implements UserInputHandler
{
    const ID = 'search_history';

    public static function get_media_url_str($category = '')
    {
        return  MediaURL::encode
                (
                    array
                    (
                        'screen_id' => self::ID,
                        'category' => $category
                    )
                );
    }

    ///////////////////////////////////////////////////////////////////////

    private $vod;
    private $skins;

    public function __construct(Vod $vod, $skins)
    {
        $this->vod = $vod;

        parent::__construct(self::ID);
        
        $this->skins = $skins;

        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }

    protected function do_get_folder_views(&$plugin_cookies)
    {
        return $this->vod->get_vod_search_history_folder_views($plugin_cookies);
    }
    ///////////////////////////////////////////////////////////////////////

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        $remove_search_action = UserInputHandlerRegistry::create_action(
                        $this, 'remove_search');
        $remove_search_action['caption'] = ("Удалить");
        
        $move_search_top_action = UserInputHandlerRegistry::create_action(
                        $this, 'move_search_top');
        $move_search_top_action['caption'] = ("Переместить вверх");
        
        $menu_items[] = array(
            GuiMenuItemDef::caption => $move_search_top_action['caption'],
           GuiMenuItemDef::action => $move_search_top_action
        );
        $menu_items[] = array(
            GuiMenuItemDef::caption => $remove_search_action['caption'],
            GuiMenuItemDef::action => $remove_search_action
        );
        
        $popup_search_action = ActionFactory::show_popup_menu($menu_items);
        
        $do_search_action = UserInputHandlerRegistry::create_action($this, 'do_search');
        
        return  array
                (
                    GUI_EVENT_KEY_ENTER => $do_search_action,
                    GUI_EVENT_KEY_POPUP_MENU => $popup_search_action
                );
    }

    public function get_handler_id()
    { return self::ID; }

    public function do_get_search_defs(&$plugin_cookies)
    {
        $defs = array();
        $search_text = isset($plugin_cookies->search) ? $plugin_cookies->search : '';
        $use_osk = isset($plugin_cookies->use_osk) ? $plugin_cookies->use_osk : 'yes';
        ControlFactory::add_text_field
        (
            $defs,
            $this,
            null,
            'search_text',
            "",
            $search_text,
            0,
            0,
            ($use_osk === 'yes' ? 1 : 0),
            true,
            1300,
            0,
            true
        );
        
        if ($use_osk === 'yes')
            ControlFactory::add_vgap($defs, 500);
        else
            ControlFactory::add_vgap($defs, 50);

        $do_new_search_action = UserInputHandlerRegistry::create_action($this, 'do_new_search');

        ControlFactory::add_custom_close_dialog_and_apply_buffon
        (
                $defs,
                'apply_subscription',
                'Искать',
                300,
                $do_new_search_action
        );
        
        ControlFactory::add_close_dialog_button
        (
            $defs,
            'Отмена',
            300
        );
        
        return $defs;
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('Search history: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        if (!isset($user_input->selected_media_url))
            return null;

        $perform_new_search_action = UserInputHandlerRegistry::create_action($this, 'perform_new_search');
            
        $media_url = MediaURL::decode($user_input->selected_media_url);

        switch ($user_input->control_id)
        {
        case 'do_search':
            if ($media_url->search_text != '')
            {
                //hd_print("--->>> search for $media_url->search_text");
                //return ActionFactory::open_folder($user_input->selected_media_url);
                $plugin_cookies->search = $media_url->search_text;
            }    

            $defs = $this->do_get_search_defs($plugin_cookies);

            return ActionFactory::show_dialog('Поиск', $defs, true);
        case 'do_new_search':
            $new_value = $plugin_cookies->search;
            // search history
            $search_items = isset($plugin_cookies->search_items) ? $plugin_cookies->search_items : '';
            $plugin_cookies->search_items = ListUtil::add_item($search_items,$new_value);
            return ActionFactory::invalidate_folders(array($user_input->parent_media_url), $perform_new_search_action);
        case 'perform_new_search':
            $new_value = $plugin_cookies->search;
            // perform search
            $search_text = urlencode($new_value);
            hd_print("Search: performing search of $search_text");
            $search_url =   $this->vod->get_search_history_media_url_str('search', $media_url->search_category, $search_text, 0);
            return ActionFactory::open_folder($search_url);
        case 'search_text':
            $new_value = $user_input->{$user_input->control_id};
            // last entered search
            $plugin_cookies->search = $new_value;
            $defs = $this->do_get_search_defs($plugin_cookies);
            return  ActionFactory::reset_controls($defs, null, 1);
        case 'remove_search':
            $ser_feed = urldecode($media_url->search_text);
            hd_print("removing search: $ser_feed");
            $search_items = isset($plugin_cookies->search_items) ? ListUtil::del_item($plugin_cookies->search_items, $ser_feed) : '';
            $plugin_cookies->search_items = $search_items;
            hd_print("-- search list: $search_items");
            return ActionFactory::invalidate_folders(array($user_input->parent_media_url), null);
        case 'move_search_top':
            $ser_feed = urldecode($media_url->search_text);
            $search_items = isset($plugin_cookies->search_items) ? $plugin_cookies->search_items : '';
            $plugin_cookies->search_items = ListUtil::add_item($search_items,$ser_feed);
            return ActionFactory::invalidate_folders(array($user_input->parent_media_url), null);
        default:
            break;
        }

        return null;
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        hd_print("--->>> Search: get_all_folder_items");
        
        $this->vod->folder_entered($media_url, $plugin_cookies);

        $items = array();
        
        $skin = $this->skins->get_current_skin($plugin_cookies);

        // add 'new search' first
        array_push
        (
            $items,
            array
            (
                PluginRegularFolderItem::caption => '[Новый запрос]',
                PluginRegularFolderItem::view_item_params => $skin->get_text_one_items_view_params($plugin_cookies),
                PluginRegularFolderItem::media_url => $this->vod->get_search_history_media_url_str('search', $media_url->category)
            )
        );

        // add user's search
        $search_items = isset($plugin_cookies->search_items) ? $plugin_cookies->search_items : '';
        foreach (ListUtil::string_to_list($search_items) as $item)
        {
            if ($item !== "")
            {
                array_push
                (
                    $items,
                    array
                    (
                        PluginRegularFolderItem::caption => "поиск: $item",
                        PluginRegularFolderItem::view_item_params => $skin->get_text_one_items_view_params($plugin_cookies),
                        PluginRegularFolderItem::media_url => $this->vod->get_search_history_media_url_str('search', $media_url->category, $item)
                    )
                );
            }
        }
        return $items;
    }

    public function get_archive(MediaURL $media_url, &$plugin_cookies)
    {
        return $this->vod->get_archive($media_url, $plugin_cookies);
    }
}

