<?php
///////////////////////////////////////////////////////////////////////////
require_once 'lib/list_util.php';

require_once 'lib/vod/abstract_vod.php';

require_once 'ExUa_movie.php';

///////////////////////////////////////////////////////////////////////////

class ExUaVod extends AbstractVod
{
    public $m_feed;
    
    private $skins;
    
    public function __construct($skins)
    {
        parent::__construct(
            ExUaConfig::VOD_FAVORITES_SUPPORTED,
            ExUaConfig::VOD_MOVIE_PAGE_SUPPORTED,
            ExUaConfig::VOD_SECTION_SEARCH_SUPPORTED,
            true);
            
        $this->skins = $skins;
    }

    ///////////////////////////////////////////////////////////////////////

    public function try_load_movie($movie_id, &$plugin_cookies)
    {
        $movie = ExUaApi::get_movie_by_id($movie_id, $plugin_cookies);
        if ($movie)
            $this->set_cached_movie($movie);
    }

    public function get_buffering_ms(&$plugin_cookies)
    {
        return isset($plugin_cookies->buf_time) ? $plugin_cookies->buf_time : 0;
    }

    public function get_vod_stream_url($playback_url, &$plugin_cookies)
    {
	    return $playback_url;
    }
    ///////////////////////////////////////////////////////////////////////
    // Favorites.

    protected function load_favorites(&$plugin_cookies)
    {
        $fav_movie_ids = $this->get_fav_movie_ids_from_cookies($plugin_cookies);

        foreach ($fav_movie_ids as $movie_id)
        {
            if ($this->has_cached_short_movie($movie_id))
                continue;

            $this->ensure_movie_loaded($movie_id, $plugin_cookies);
        }

        $this->set_fav_movie_ids($fav_movie_ids);

        hd_print('The ' . count($fav_movie_ids) . ' favorite movies loaded.');
    }

    protected function do_save_favorite_movies(&$fav_movie_ids, &$plugin_cookies)
    {
        $this->set_fav_movie_ids_to_cookies($plugin_cookies, $fav_movie_ids);
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_fav_movie_ids_from_cookies(&$plugin_cookies)
    {
        $items = array();
        
        $fav_items = isset($plugin_cookies->fav_items) ? $plugin_cookies->fav_items : '';

        foreach (ListUtil::string_to_list($fav_items) as $item)
        {
            if ($item !== "")
            {
                $items[] = $item;
            }
        }
        
        return $items;
    }

    public function is_favorite_movie_id($movie_id, $plugin_cookies)
    {
        $fav_items = isset($plugin_cookies->fav_items) ? $plugin_cookies->fav_items : '';

        return ListUtil::is_in_list($fav_items, $movie_id);
    }

    protected function do_add_favorite_movie($movie_id, &$plugin_cookies)
    {
        $fav_items = isset($plugin_cookies->fav_items) ? $plugin_cookies->fav_items : '';
        $plugin_cookies->fav_items = ListUtil::add_item($fav_items, $movie_id);
        $movie = ExUaApi::get_movie_by_id($movie_id, $plugin_cookies);
        if (!$movie)
            return;
            
        $plugin_cookies->$movie_id = '';    
        
        foreach($movie->series_list as $s)
        {
            if (strlen($s->playback_url) == 0)
                continue;
                
            $i = $plugin_cookies->$movie_id;
            
            $plugin_cookies->$movie_id = ListUtil::add_item($i, $s->playback_url);
        }
    }

    protected function do_remove_favorite_movie($movie_id, &$plugin_cookies)
    {
        $fav_items = isset($plugin_cookies->fav_items) ? ListUtil::del_item($plugin_cookies->fav_items, $movie_id) : '';
        $plugin_cookies->fav_items = $fav_items;
        if (isset($plugin_cookies->$movie_id))
        {
            unset($plugin_cookies->$movie_id);
        }
        $s = $movie_id . ".viewed";
        if (isset($plugin_cookies->$s))
        {
            unset($plugin_cookies->$s);
        }
    }
    
    public function set_fav_movie_ids_to_cookies(&$plugin_cookies, &$ids)
    {

    }


    ///////////////////////////////////////////////////////////////////////
    // Search.

    public function get_section_search_url($media_url, &$plugin_cookies)
    {
        $id = ExUaApi::get_search_category_id($media_url->category_id, $plugin_cookies);
        if ($id == false)
            return false;
        
        return ExUa_search_history::get_media_url_str($id);
    }
    public function get_search_history_media_url_str($cat_id, $cat_search, $pattern = '', $movie_id = 0)
    {
        return ExUaVodListScreen::get_media_url_str($cat_id == '' ? 'search' : $cat_id, $cat_search, $pattern, $movie_id);
    }
/*
    public function get_search_media_url_str($pattern)
    {
        return ExUaVodListScreen::get_media_url_str('search', $pattern);
    }
*/

    ///////////////////////////////////////////////////////////////////////
    // Folder views.

   public function folder_entered(MediaURL $media_url, &$plugin_cookies)
   {

   }
   
    public function get_vod_list_folder_views(&$plugin_cookies)
    {
        return $this->skins->get_current_skin($plugin_cookies)->GET_VOD_MOVIE_LIST_FOLDER_VIEWS($plugin_cookies);
//        return ExUaConfig::GET_VOD_MOVIE_LIST_FOLDER_VIEWS($plugin_cookies);
    }

    public function get_vod_search_history_folder_views(&$plugin_cookies)
    {
        return $this->skins->get_current_skin($plugin_cookies)->GET_TEXT_ONE_COL_VIEWS($plugin_cookies);
//        return ExUaConfig::GET_TEXT_ONE_COL_VIEWS();
    }
}

///////////////////////////////////////////////////////////////////////////
?>
