<?php
///////////////////////////////////////////////////////////////////////////
require_once 'lib/vod/vod_list_screen.php';

require_once 'ExUa_api.php';
require_once 'ExUa_movie.php';

class ExUaVodListScreen extends VodListScreen
{
    private $skins;
    public static function get_media_url_str($cat_id, $search_category = false, $search_text = '', $movie_id = 0)
    {
        $arr['screen_id'] = self::ID;
        $arr['category_id'] = $cat_id;
        $arr['search_category'] = $search_category;
        $arr['search_text'] = $search_text;
        $arr['movie_id'] = $movie_id;
        return MediaURL::encode($arr);
    }

    ///////////////////////////////////////////////////////////////////////

    public function __construct(Vod $vod, $skins)
    {
        parent::__construct($vod);
        
        $this->skins = $skins;
    }

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        $actions = array();

        $add_action = UserInputHandlerRegistry::create_action($this, 'mark_viewed');
        $add_action['caption'] = 'Просмотрено/Не просмотрено';
        
        $actions[GUI_EVENT_KEY_B_GREEN] = $add_action;

        if ($this->vod->is_movie_page_supported())
            $actions[GUI_EVENT_KEY_ENTER] = ActionFactory::open_folder();
        else
            $actions[GUI_EVENT_KEY_ENTER] = ActionFactory::vod_play();

        if ($this->vod->is_favorites_supported())
        {
            $add_favorite_action =
                UserInputHandlerRegistry::create_action(
                    $this, 'add_favorite');
            $add_favorite_action['caption'] = 'Добавить в Избранное';

            $popup_menu_action =
                UserInputHandlerRegistry::create_action(
                    $this, 'popup_menu');

            $actions[GUI_EVENT_KEY_C_YELLOW] = $add_favorite_action;
        }

        if ($this->vod->is_section_search_supported())
        {
            $search = UserInputHandlerRegistry::create_action(
                            $this, 'category_search');
            $search['caption'] = 'Поиск в разделе';
            $actions[GUI_EVENT_KEY_D_BLUE] = $search;
        }
        return $actions;
        
    }

    private function _mark_as_viewed($movie_id, &$error_msg, &$plugin_cookies)
    {
        $error_msg = '';
        if (!isset($plugin_cookies->fav_items))
            $plugin_cookies->fav_items = '';
        $movie = ExUaApi::get_movie_by_id($movie_id, $plugin_cookies);
        if (!$movie)
            return false;

        if (count($movie->series_list) > 1)
        {
            $error_msg = 'Нельзя поменять состояние для многосерийных фильмов.|Но Вы можете изменить состояние для каждой одельной серии.';
            return false;
        }
            
        $url = $movie->series_list[0]->playback_url;
        
        if
        (
            isset($plugin_cookies->fav_items) &&
            ListUtil::is_in_list($plugin_cookies->fav_items, $movie_id)
        )
        {
            $s = $movie_id . ".viewed";
            if (!isset($plugin_cookies->$s))
                $plugin_cookies->$s = '';
            if (!ListUtil::is_in_list($plugin_cookies->$s, $url))
            {
                $i = $plugin_cookies->$s;       
                $plugin_cookies->$s = ListUtil::add_item($i, $url);
            }
            else
            {
                $i = $plugin_cookies->$s;       
                $plugin_cookies->$s = ListUtil::del_item($i, $url);
            }
        }
        
        $key = $movie_id . '.' . $url;
        if (isset($plugin_cookies->$key))
        {
            unset($plugin_cookies->$key);
        }
        else if
        (
            !isset($plugin_cookies->fav_items) ||
            !ListUtil::is_in_list($plugin_cookies->fav_items, $movie_id)
        )
        {
            $plugin_cookies->$key = '-1|-1';
        }
        
        $error_msg = 'Экран обновится при следующем вхождении в эту папку.';
        return false;
    }
    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('Vod favorites: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        if (!isset($user_input->selected_media_url))
            return null;

        $media_url = MediaURL::decode($user_input->selected_media_url);
        $movie_id = $media_url->movie_id;

        $is_favorite = $this->vod->is_favorite_movie_id($movie_id, $plugin_cookies);
        
        if ($user_input->control_id == 'popup_menu')
        {
            if ($is_favorite)
            {
                $favorite_action =
                    UserInputHandlerRegistry::create_action(
                        $this, 'remove_favorite');
                $caption = 'Удалить из Избранного';
            }
            else
            {
                $favorite_action =
                    UserInputHandlerRegistry::create_action(
                        $this, 'add_favorite');
                $caption = 'Добавить в Избранное';
            }
            $menu_items[] = array(
                GuiMenuItemDef::caption => $caption,
                GuiMenuItemDef::action => $favorite_action);

            return ActionFactory::show_popup_menu($menu_items);
        }
        else if ($user_input->control_id == 'add_favorite')
        {
            if ($is_favorite)
            {
                return ActionFactory::show_title_dialog('Видео уже в Избранном');
            }
            else
            {
                $this->vod->add_favorite_movie($movie_id, $plugin_cookies);

                return ActionFactory::show_title_dialog('Видео добавлено в избранное');
            }
        }
        else if ($user_input->control_id == 'remove_favorite')
        {
            $this->vod->remove_favorite_movie($movie_id, $plugin_cookies);

            return ActionFactory::invalidate_folders(array($user_input->parent_media_url), null);
        }
        else if ($user_input->control_id == 'category_search')
        {
            $parent_media_url = MediaURL::decode($user_input->parent_media_url);
            $url = $this->vod->get_section_search_url($parent_media_url, $plugin_cookies);
            if ($url == false)
                return ActionFactory::show_title_dialog('Для этой категории нет поиска');
        
            return ActionFactory::open_folder($url);
        }
        else if ($user_input->control_id == 'mark_viewed')
        {
            $error_msg = '';
            if (!$this->_mark_as_viewed($movie_id, $error_msg, $plugin_cookies))
            {
                if (mb_strlen($error_msg) > 0)
                {
                    $lines = explode('|', $error_msg);
                    return ActionFactory::show_error(false, '', $lines);
                }
                else
                    return null;
            }
            
            return ActionFactory::invalidate_folders(array($user_input->parent_media_url), null);
        }
        
        return parent::handle_user_input(&$user_input, &$plugin_cookies);
    }
    ///////////////////////////////////////////////////////////////////////
    protected function get_short_movie_range(MediaURL $media_url, $from_ndx,
        &$plugin_cookies)
    {
        if ($media_url->category_id == 'search')
        {
            $movies = ExUaApi::search_get_items($media_url->search_text, $this->vod->m_feed, $media_url->search_category, false, $plugin_cookies);
        }
        else if ($media_url->category_id == 'sub_view')
        {
            $movies = ExUaApi::get_items($media_url->search_category, $this->vod->m_feed, $media_url->category_id, false, $plugin_cookies);
        }
        else
        {
            $movies = ExUaApi::get_items(false, $this->vod->m_feed, $media_url->category_id, false, $plugin_cookies);
        }
        
        $nMovies = count($movies);
        hd_print("--->>> nMovies: $nMovies");

        return new ShortMovieRange($from_ndx, count($movies), $movies);
    }
    public static function add_movie($movie, $view_type, $skin, &$items, &$plugin_cookies)
    {
        $murl = ExUaVodMovieScreen::get_media_url_str($movie->id);
        if ($movie->has_sub_view)
        {
           $murl = self::get_media_url_str('sub_view', $movie->sub_view_url, '', $movie->id);
        }
        
        $caption = $movie->name;
        if ($movie->has_new_series)
            $caption = "[НОВАЯ] " . $caption;
                
        if (!is_null($movie->series_list) && count($movie->series_list) == 1)
        {
            $movie_id = $movie->id;
            $playback_url = $movie->series_list[0]->playback_url;
            $is_audio = $movie->series_list[0]->is_audio;
            $resume_audio = isset($plugin_cookies->resume_audio) ? $plugin_cookies->resume_audio : 'no';
            if (!$is_audio || $resume_audio == 'yes')
            {
                $key = $movie_id . '.' . $playback_url;
                if (isset($plugin_cookies->$key))
                {
                    $t = explode('|', $plugin_cookies->$key);
                    if (intval($t[0]) != -1)
                        $caption = '[ПРОСМ ' . HD::format_duration(intval($t[0]) * 1000) . '/' . HD::format_duration(intval($t[1]) * 1000) . '] ' . $caption;
                    else
                        $caption = '[ПРОСМ] ' . $caption;
                }
            }
        }
        
        array_push
        (
            $items,
            array
            (
                PluginRegularFolderItem::media_url => $murl,
                PluginRegularFolderItem::caption => $caption,
                PluginRegularFolderItem::view_item_params => $skin->get_vod_movie_items_view_params
                                (
                                    ExUaApi::get_short_title($movie, $view_type),
                                    $movie->poster_url,
                                    $view_type,
                                    $plugin_cookies
                                )
            )
        );

    }
    public function get_folder_range(MediaURL $media_url, $from_ndx, &$plugin_cookies)
    {
        hd_print("--->>> get_folder_range from_ndx $from_ndx");

        $movie_range = $this->get_short_movie_range($media_url, $from_ndx, $plugin_cookies);

        $total = intval($movie_range->total);
        if ($total < 0)
            return HD::create_regular_folder_range(array());

        $skin = $this->skins->get_current_skin($plugin_cookies);
        $view_type = $this->get_folder_view_index($plugin_cookies);
        
        $total_num = 0;    
        $items = array();
        foreach ($movie_range->short_movies as $movie)
        {
            ++$total_num;
            
            self::add_movie($movie, $view_type, $skin, $items, $plugin_cookies);
            
            $this->vod->set_cached_movie($movie);
        }

        array_push
        (
            $items,
            array
            (
                PluginRegularFolderItem::media_url => 'dummy',
                PluginRegularFolderItem::caption => $total == 0 ? 'Больше ничего не найдено' : 'Загрузка...',
                PluginRegularFolderItem::view_item_params => $skin->get_vod_movie_items_view_params
                                                            (
                                                                false,
                                                                false,
                                                                $view_type,
                                                                $plugin_cookies
                                                            )
            )    
        );
        if ($movie_range->from_ndx == 0)
            ++$total_num;

        return  HD::create_regular_folder_range
                (
                    $items,
                    $movie_range->from_ndx > 0 ? $movie_range->from_ndx - 1 : 0,
                    $movie_range->from_ndx+$total_num,
                    count($movie_range->short_movies) > 0
                );
    }

    public function get_folder_view(MediaURL $media_url, &$plugin_cookies)
    {
       $this->vod->m_feed = 0;

       return parent::get_folder_view($media_url, $plugin_cookies);
    }
}

///////////////////////////////////////////////////////////////////////////
?>
