<?php
///////////////////////////////////////////////////////////////////////////
require_once 'lib/list_util.php';

require_once 'lib/screen.php';
require_once 'lib/vod/vod.php';
require_once 'lib/vod/movie.php';
require_once 'lib/vod/vod_series_list_screen.php';
require_once 'lib/vod/vod_movie_screen.php';

class ExUaVodMovieScreen extends VodMovieScreen
//implements Screen, UserInputHandler
{
//    const ID = 'ex_vod_movie';

    public static function get_media_url_str($movie_id)
    {
        return MediaURL::encode(
            array(
                'screen_id' => self::ID,
                'movie_id' => $movie_id));
    }

    ///////////////////////////////////////////////////////////////////////

    public function __construct(Vod $vod)
    {
        parent::__construct($vod);
    }

    ///////////////////////////////////////////////////////////////////////

//    public function get_id()
//    { return self::ID; }

//    public function get_handler_id()
//    { return self::ID; }

    ///////////////////////////////////////////////////////////////////////

    public function get_folder_view(MediaURL $media_url, &$plugin_cookies)
    {
        $this->vod->folder_entered($media_url, $plugin_cookies);

        $movie = $this->vod->get_loaded_movie($media_url->movie_id, $plugin_cookies);
        if ($movie === null)
        {
            // TODO: dialog?
            return null;
        }

        $has_right_button = true;//$this->vod->is_favorites_supported();
        $right_button_caption = null;
        $right_button_action = null;
        $right_button_action = UserInputHandlerRegistry::create_action(
                    $this, 'additional');
        $right_button_action['caption'] = "Действия";

        $movie_folder_view = array
        (
            PluginMovieFolderView::movie => $movie->get_movie_array(),
            PluginMovieFolderView::has_right_button => $has_right_button,
            PluginMovieFolderView::right_button_caption => $right_button_action['caption'],
            PluginMovieFolderView::right_button_action => $right_button_action,
            PluginMovieFolderView::has_multiple_series =>
                (count($movie->series_list) > 1),
            PluginMovieFolderView::series_media_url =>
                ExUaVodSeriesListScreen::get_media_url_str($movie->id),
        );

        return array
        (
            PluginFolderView::multiple_views_supported  => false,
            PluginFolderView::archive                   => null,
            PluginFolderView::view_kind                 => PLUGIN_FOLDER_VIEW_MOVIE,
            PluginFolderView::data                      => $movie_folder_view,
        );
    }

    ///////////////////////////////////////////////////////////////////////
    public function do_get_search_defs(&$plugin_cookies)
    {
        $defs = array();
        $search_text = isset($plugin_cookies->search) ? $plugin_cookies->search : '';
        $use_osk = isset($plugin_cookies->use_osk) ? $plugin_cookies->use_osk : 'yes';
        ControlFactory::add_text_field
        (
            $defs,
            $this,
            null,
            'search_text',
            "",
            $search_text,
            0,
            0,
            ($use_osk === 'yes' ? 1 : 0),
            true,
            1300,
            0,
            true
        );
        
        if ($use_osk === 'yes')
            ControlFactory::add_vgap($defs, 500);
        else
            ControlFactory::add_vgap($defs, 50);

        $do_new_search_action = UserInputHandlerRegistry::create_action($this, 'do_new_search');

        ControlFactory::add_custom_close_dialog_and_apply_buffon
        (
                $defs,
                'apply_subscription',
                'Искать',
                300,
                $do_new_search_action
        );
        
        ControlFactory::add_close_dialog_button
        (
            $defs,
            'Отмена',
            300
        );
        
        return $defs;
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('Movie: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        $media_url = MediaURL::decode($user_input->selected_media_url);
        $movie_id = $media_url->movie_id;

        $is_favorite = $this->vod->is_favorite_movie_id($movie_id, $plugin_cookies);
        
        hd_print("--->>> $movie_id : $is_favorite");
        
/*        if ($user_input->control_id == 'favorites')
        {
            $is_favorite = $this->vod->is_favorite_movie_id($movie_id, $plugin_cookies);
            if ($is_favorite)
                $this->vod->remove_favorite_movie($movie_id, $plugin_cookies);
            else
                $this->vod->add_favorite_movie($movie_id, $plugin_cookies);

            $message = $is_favorite ?
                T::t('vod_movie_removed_from_my_movies') :
                T::t('vod_movie_added_to_my_movies');

            return ActionFactory::show_title_dialog($message,
                ActionFactory::invalidate_folders(
                    array(
                        self::get_media_url_str($movie_id),
                        ExUaVodFavoritesScreen::get_media_url_str(),
                    )));
        }
        else */
        if ($user_input->control_id == 'additional')
        {
            $do_search_alt = UserInputHandlerRegistry::create_action($this, 'do_search_alt');
            $add_fav = UserInputHandlerRegistry::create_action($this, 'add_favorite');
            $remove_fav = UserInputHandlerRegistry::create_action($this, 'remove_favorite');
            
            $defs = array();
            ControlFactory::add_custom_close_dialog_and_apply_buffon
            (
                $defs,
                '_favorites',
                 ($is_favorite ? 'Удалить из Избранного' : 'Добавить в Избранное'),
                  500,
                  ($is_favorite ? $remove_fav : $add_fav)
            );
            ControlFactory::add_custom_close_dialog_and_apply_buffon($defs,'_search', 'Поиск', 500, $do_search_alt);
            ControlFactory::add_close_dialog_button($defs, 'Назад', 500);
            return ActionFactory::show_dialog('Действия', $defs);
        }
        else if ($user_input->control_id == 'do_search_alt')
        {
            $movie = $this->vod->get_cached_movie($movie_id);
            $title = $movie->name;
            $plugin_cookies->search = $title;
            $defs = $this->do_get_search_defs($plugin_cookies);
            return ActionFactory::show_dialog('Поиск', $defs);
        }
        else if ($user_input->control_id == 'do_new_search')
        {
            $new_value = $plugin_cookies->search;
            // search history
            $search_items = isset($plugin_cookies->search_items) ? $plugin_cookies->search_items : '';
            $plugin_cookies->search_items = ListUtil::add_item($search_items,$new_value);

            $search_text = urlencode($new_value);
            hd_print("Search: performing search of $search_text");
            $search_url =   $this->vod->get_search_history_media_url_str('search', false, $search_text);
            return ActionFactory::open_folder($search_url);
//            return ActionFactory::invalidate_folders(array($user_input->parent_media_url), $perform_new_search_action);
        }    
        else if ($user_input->control_id == 'perform_new_search')
        {
            $new_value = $plugin_cookies->search;
            // perform search
            $search_text = urlencode($new_value);
            hd_print("Search: performing search of $search_text");
            $search_url =   $this->vod->get_search_history_media_url_str('search', false, $search_text, 0);
            return ActionFactory::open_folder($search_url);
        }    
        else if ($user_input->control_id == 'search_text')
        {
            $new_value = $user_input->{$user_input->control_id};
            // last entered search
            $plugin_cookies->search = $new_value;
            $defs = $this->do_get_search_defs($plugin_cookies);
            return  ActionFactory::reset_controls($defs, null, 1);
        }    
        else if ($user_input->control_id == 'add_favorite')
        {
            if ($is_favorite)
            {
                return ActionFactory::show_title_dialog('Видео уже в Избранном');
            }
            else
            {
                $this->vod->add_favorite_movie($movie_id, $plugin_cookies);

                return ActionFactory::show_title_dialog('Видео добавлено в избранное');
            }
        }
        else if ($user_input->control_id == 'remove_favorite')
        {
            $this->vod->remove_favorite_movie($movie_id, $plugin_cookies);

            return  ActionFactory::invalidate_folders
                    (
                        array(ExUaVodFavoritesScreen::get_media_url_str()),
                        ActionFactory::show_title_dialog('Видео было удалено из избранного')
                    );
        }
        return null;
    }
}

///////////////////////////////////////////////////////////////////////////
?>
