<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/vod/vod.php';
require_once 'lib/vod/vod_series_list_screen.php';
require_once 'lib/abstract_preloaded_regular_screen.php';
require_once 'lib/list_util.php';


class ExUaVodSeriesListScreen extends VodSeriesListScreen implements UserInputHandler
{
//    const ID = 'ex_vod_series';

    public static function get_media_url_str($movie_id)
    {
        return MediaURL::encode(
            array(
                'screen_id' => self::ID,
                'movie_id' => $movie_id));
    }

    ///////////////////////////////////////////////////////////////////////

    public function __construct(Vod $vod)
    {
        parent::__construct($vod);

        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_handler_id()
    { return self::ID; }

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        $this->vod->folder_entered($media_url, $plugin_cookies);

        $movie = $this->vod->get_loaded_movie($media_url->movie_id, $plugin_cookies);
        if ($movie === null)
        {
            // TODO: dialog?
            return array();
        }
            
        $resume_audio = isset($plugin_cookies->resume_audio) ? $plugin_cookies->resume_audio : 'no';

        $items = array();

        foreach ($movie->series_list as $series)
        {
            $caption = '';
            $movie_id = $movie->id;
            if (isset($plugin_cookies->$movie_id))
            {
                if (!ListUtil::is_in_list($plugin_cookies->$movie_id, $series->playback_url))
                    $caption = '[НОВАЯ] ';
            }
            
            if (!$series->is_audio || $resume_audio == 'yes')
            {
                $key = $movie_id . '.viewed';
                if (isset($plugin_cookies->$key))
                {
                    if (ListUtil::is_in_list($plugin_cookies->$key, $series->playback_url))
                        $caption = '[ПРОСМ] ';
                }
                
                $key = $movie_id . '.' . $series->playback_url;
                if (isset($plugin_cookies->$key))
                {
                    $t = explode('|', $plugin_cookies->$key);
                    if (intval($t[0]) != -1)
                        $caption = '[ПРОСМ ' . HD::format_duration(intval($t[0]) * 1000) . '/' . HD::format_duration(intval($t[1]) * 1000) . '] ';
                    else
                        $caption = '[ПРОСМ] ';
                }
            }
                        
            $caption = $caption . $series->name;

            $items[] = array
            (
                PluginRegularFolderItem::media_url =>
                    MediaURL::encode(
                        array
                        (
                            'screen_id' => self::ID,
                            'movie_id' => $movie->id,
                            'series_id'  => $series->id,
                        )),
                PluginRegularFolderItem::caption => $caption,
                PluginRegularFolderItem::view_item_params => array
                (
                    ViewItemParams::icon_path => 'gui_skin://small_icons/movie.aai',
                ),
            );
        }

        return $items;
    }

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        $add_action = UserInputHandlerRegistry::create_action($this, 'mark_viewed');
        $add_action['caption'] = 'Просмотрено/Не просмотрено';
        
        return  array
                (
                    GUI_EVENT_KEY_ENTER => ActionFactory::vod_play(),
                    GUI_EVENT_KEY_PLAY  => ActionFactory::vod_play(),
                    GUI_EVENT_KEY_B_GREEN => $add_action
                );
    }

    private function _mark_as_viewed($movie_id, $series_idx, &$error_msg, &$plugin_cookies)
    {
        $error_msg = '';
        if (!isset($plugin_cookies->fav_items))
            $plugin_cookies->fav_items = '';
        $movie = ExUaApi::get_movie_by_id($movie_id, $plugin_cookies);
        if (!$movie)
            return false;
        
        if ($movie->series_list[$series_idx]->is_audio)
        {
            $resume_audio = isset($plugin_cookies->resume_audio) ? $plugin_cookies->resume_audio : 'no';
            if ($resume_audio == 'no')
            {
                $error_msg = 'Эта функция не работает для аудио файлов|с выключеной опцией "Автовозобновление аудиофайлов"';
                return false;
            }
        }
        $url = $movie->series_list[$series_idx]->playback_url;
            
        if
        (
            isset($plugin_cookies->fav_items) &&
            ListUtil::is_in_list($plugin_cookies->fav_items, $movie_id)
        )
        {
            if (isset($plugin_cookies->$movie_id))
            {
                if (!ListUtil::is_in_list($plugin_cookies->$movie_id, $url))
                {
                    $viewed = $plugin_cookies->$movie_id;
                    $plugin_cookies->$movie_id = ListUtil::add_item($viewed,$url);
                }
            }
            else
            {
                $plugin_cookies->$video_id = $url;
            }
            $s = $movie_id . ".viewed";
            if (!isset($plugin_cookies->$s))
                $plugin_cookies->$s = '';
            if (!ListUtil::is_in_list($plugin_cookies->$s, $url))
            {
                $i = $plugin_cookies->$s;       
                $plugin_cookies->$s = ListUtil::add_item($i, $url);
            }
            else
            {
                $i = $plugin_cookies->$s;       
                $plugin_cookies->$s = ListUtil::del_item($i, $url);
            }
        }
        
        $key = $movie_id . '.' . $url;
        if (isset($plugin_cookies->$key))
        {
            unset($plugin_cookies->$key);
        }
        else if
        (
            !isset($plugin_cookies->fav_items) ||
            !ListUtil::is_in_list($plugin_cookies->fav_items, $movie_id)
        )
        {
            $plugin_cookies->$key = '-1|-1';
        }
        
        return true;
    }
    
    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('vod_series_list: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");
            
        $media_url = MediaURL::decode($user_input->selected_media_url);

        switch ($user_input->control_id)
        {
        case 'mark_viewed':
            $error_msg = '';
            if (!$this->_mark_as_viewed($media_url->movie_id, $media_url->series_id, $error_msg, $plugin_cookies))
            {
                if (mb_strlen($error_msg) > 0)
                {
                    $lines = explode('|', $error_msg);
                    return ActionFactory::show_error(false, '', $lines);
                }
                else
                    return null;
            }
            
            return ActionFactory::invalidate_folders(array($user_input->parent_media_url), null);
        }
        
        return null;
    }
}

///////////////////////////////////////////////////////////////////////////
?>
